library(coin)

setwd("C:\\varmechanisms")

options(warn=-1) 

d = read.csv("results-coded.csv")

install.packages("effsize")
library(effsize)

# Definition of A12 according to http://doofussoftware.blogspot.com/2012/07/measuring-effect-size-with-vargha.html
# with pointers "Eqn 13 and 14" referring to Vargha and Delaney's paper

AMeasure <- function(a,b){
    # Compute the rank sum (Eqn 13)
    r = rank(c(a,b))
    r1 = sum(r[seq_along(a)])

    # Compute the measure (Eqn 14) 
    m = length(a)
    n = length(b)
    A = (r1/m - (m+1)/2)/n

    A
}


# RQ1: Correctness

 r1 <- function(arg1) { round(arg1, digits=1) }
paste(
 "&", r1(mean(d$ann12, na.rm=TRUE)), "&", r1(median(d$ann12, na.rm=TRUE)), "&" , r1(sd(d$ann12, na.rm=TRUE)), "&",
 r1(mean(d$com12, na.rm=TRUE)), "&", r1(median(d$com12, na.rm=TRUE)), "&" , r1(sd(d$com12, na.rm=TRUE)), "&",
 r1(mean(d$enu12, na.rm=TRUE)), "&", r1(median(d$enu12, na.rm=TRUE)), "&" , r1(sd(d$enu12, na.rm=TRUE)) 
)
paste(
"&", r1(mean(d$ann34, na.rm=TRUE)), "&", r1(median(d$ann34, na.rm=TRUE)), "&" , r1(sd(d$ann34, na.rm=TRUE)), "&",
 r1(mean(d$com34, na.rm=TRUE)), "&", r1(median(d$com34, na.rm=TRUE)), "&" , r1(sd(d$com34, na.rm=TRUE)), "&",
 r1(mean(d$enu34, na.rm=TRUE)), "&", r1(median(d$enu34, na.rm=TRUE)), "&" , r1(sd(d$enu34, na.rm=TRUE)) 
)
paste(
"&", r1(mean(d$ann56, na.rm=TRUE)), "&", r1(median(d$ann56, na.rm=TRUE)), "&" , r1(sd(d$ann56, na.rm=TRUE)), "&",
 r1(mean(d$com56, na.rm=TRUE)), "&", r1(median(d$com56, na.rm=TRUE)), "&" , r1(sd(d$com56, na.rm=TRUE)), "&",
 r1(mean(d$enu56, na.rm=TRUE)), "&", r1(median(d$enu56, na.rm=TRUE)), "&" , r1(sd(d$enu56, na.rm=TRUE)) 
)
annall <- d$ann12+d$ann34+d$ann56
comall <- d$com12+d$com34+d$com56
enuall <- d$enu12+d$enu34+d$enu56
paste(
"&", r1(mean(annall, na.rm=TRUE)), "&", r1(median(annall, na.rm=TRUE)), "&" , r1(sd(annall, na.rm=TRUE)), "&",
 r1(mean(comall, na.rm=TRUE)), "&", r1(median(comall, na.rm=TRUE)), "&" , r1(sd(comall, na.rm=TRUE)), "&",
 r1(mean(enuall, na.rm=TRUE)), "&", r1(median(enuall, na.rm=TRUE)), "&" , r1(sd(enuall, na.rm=TRUE)) 
)



pval <- function(arg1) { arg1$p.value }
paste(r2(pval(wilcox.test(d$ann12,d$com12,paired=TRUE))),r2(pval(wilcox.test(d$ann12,d$enu12,paired=TRUE))),r2(pval(wilcox.test(d$com12,d$enu12,paired=TRUE))))
paste(r2(pval(wilcox.test(d$ann34,d$com34,paired=TRUE))),r2(pval(wilcox.test(d$enu34,d$ann34,paired=TRUE))),r2(pval(wilcox.test(d$com34,d$enu34,paired=TRUE))))
paste(r2(pval(wilcox.test(d$ann56,d$com56,paired=TRUE))),r2(pval(wilcox.test(d$ann56,d$enu56,paired=TRUE))),r2(pval(wilcox.test(d$com56,d$enu56,paired=TRUE))))

paste(r2(AMeasure(d$ann12,d$com12)),r2(AMeasure(d$ann12,d$enu12)),r2(AMeasure(d$enu12,d$com12)))
paste(r2(AMeasure(d$ann34,d$com34)),r2(AMeasure(d$ann34,d$enu34)),r2(AMeasure(d$enu34,d$com34)))
paste(r2(AMeasure(d$ann56,d$com56)),r2(AMeasure(d$ann56,d$enu56)),r2(AMeasure(d$enu56,d$com56)))




# RQ1: Time

 r1 <- function(arg1) { round(arg1, digits=1) }
 paste(min(d$timeann, na.rm=TRUE), "&", r1(mean(d$timeann, na.rm=TRUE)), "&", r1(median(d$timeann, na.rm=TRUE)), "&" , max(d$timeann, na.rm=TRUE) , "&" , r1(sd(d$timeann, na.rm=TRUE)) )
 paste(min(d$timecom, na.rm=TRUE), "&", r1(mean(d$timecom, na.rm=TRUE)), "&", r1(median(d$timecom, na.rm=TRUE)), "&" , max(d$timecom, na.rm=TRUE) , "&" , r1(sd(d$timecom, na.rm=TRUE)) ) 
 paste(min(d$timeenu, na.rm=TRUE), "&", r1(mean(d$timeenu, na.rm=TRUE)), "&", r1(median(d$timeenu, na.rm=TRUE)), "&" , max(d$timeenu, na.rm=TRUE) , "&" , r1(sd(d$timeenu, na.rm=TRUE)) )
install.packages("coin")
library(coin)
r2 <- function(arg1) { round(arg1, digits=4) }
timesann <- d[complete.cases(d$timeann),]$timeann
timescom <- d[complete.cases(d$timecom),]$timecom
timesenu <- d[complete.cases(d$timeenu),]$timeenu
paste(r2(pvalue(wilcoxsign_test(timesann~timescom,d))),r2(pvalue(wilcoxsign_test(timesann~timesenu,d))),r2(pvalue(wilcoxsign_test(timescom~timesenu,d))))

paste(r2(AMeasure(timescom,timesann)),r2(AMeasure(timesenu,timesann)),r2(AMeasure(timescom,timesenu)))




# RQ2: Subjective ratings


r1 <- function(arg1) { round(arg1, digits=1) }
paste(
 "&", r1(mean(d$undann, na.rm=TRUE)), "&", r1(median(d$undann, na.rm=TRUE)), "&" , r1(sd(d$undann, na.rm=TRUE)), "&",
 r1(mean(d$undcom, na.rm=TRUE)), "&", r1(median(d$undcom, na.rm=TRUE)), "&" , r1(sd(d$undcom, na.rm=TRUE)), "&",
 r1(mean(d$undenu, na.rm=TRUE)), "&", r1(median(d$undenu, na.rm=TRUE)), "&" , r1(sd(d$undenu, na.rm=TRUE)) 
)
paste(
 "&", r1(mean(d$diff12ann, na.rm=TRUE)), "&", r1(median(d$diff12ann, na.rm=TRUE)), "&" , r1(sd(d$diff12ann, na.rm=TRUE)), "&",
 r1(mean(d$diff12com, na.rm=TRUE)), "&", r1(median(d$diff12com, na.rm=TRUE)), "&" , r1(sd(d$diff12com, na.rm=TRUE)), "&",
 r1(mean(d$diff12enu, na.rm=TRUE)), "&", r1(median(d$diff12enu, na.rm=TRUE)), "&" , r1(sd(d$diff12enu, na.rm=TRUE)) 
)
paste(
 "&", r1(mean(d$diff34ann, na.rm=TRUE)), "&", r1(median(d$diff34ann, na.rm=TRUE)), "&" , r1(sd(d$diff34ann, na.rm=TRUE)), "&",
 r1(mean(d$diff34com, na.rm=TRUE)), "&", r1(median(d$diff34com, na.rm=TRUE)), "&" , r1(sd(d$diff34com, na.rm=TRUE)), "&",
 r1(mean(d$diff34enu, na.rm=TRUE)), "&", r1(median(d$diff34enu, na.rm=TRUE)), "&" , r1(sd(d$diff34enu, na.rm=TRUE)) 
)
paste(
 "&", r1(mean(d$diff56ann, na.rm=TRUE)), "&", r1(median(d$diff56ann, na.rm=TRUE)), "&" , r1(sd(d$diff56ann, na.rm=TRUE)), "&",
 r1(mean(d$diff56com, na.rm=TRUE)), "&", r1(median(d$diff56com, na.rm=TRUE)), "&" , r1(sd(d$diff56com, na.rm=TRUE)), "&",
 r1(mean(d$diff56enu, na.rm=TRUE)), "&", r1(median(d$diff56enu, na.rm=TRUE)), "&" , r1(sd(d$diff56enu, na.rm=TRUE)) 
)
   
pval <- function(arg1) { arg1$p.value }
paste(r2(pval(wilcox.test(d$undann,d$undcom,paired=TRUE))),r2(pval(wilcox.test(d$undann,d$undenu,paired=TRUE))),r2(pval(wilcox.test(d$undcom,d$undenu,paired=TRUE))))
paste(r2(pval(wilcox.test(d$diff12ann,d$diff12com,paired=TRUE))),r2(pval(wilcox.test(d$diff12ann,d$diff12enu,paired=TRUE))),r2(pval(wilcox.test(d$diff12com,d$diff12enu,paired=TRUE))))
paste(r2(pval(wilcox.test(d$diff34ann,d$diff34com,paired=TRUE))),r2(pval(wilcox.test(d$diff34ann,d$diff34enu,paired=TRUE))),r2(pval(wilcox.test(d$diff34com,d$diff34enu,paired=TRUE))))
paste(r2(pval(wilcox.test(d$diff56ann,d$diff56com,paired=TRUE))),r2(pval(wilcox.test(d$diff56ann,d$diff56enu,paired=TRUE))),r2(pval(wilcox.test(d$diff56com,d$diff56enu,paired=TRUE))))


paste(r2(AMeasure(d$undcom,d$undann)),r2(AMeasure(d$undann,d$undenu)),r2(AMeasure(d$undcom,d$undenu)))
paste(r2(AMeasure(d$diff12com,d$diff12ann)),r2(AMeasure(d$diff12enu,d$diff12ann)),r2(AMeasure(d$diff12com,d$diff12enu)))
paste(r2(AMeasure(d$diff34com,d$diff34ann)),r2(AMeasure(d$diff34enu,d$diff34ann)),r2(AMeasure(d$diff34com,d$diff34enu)))
paste(r2(AMeasure(d$diff56com,d$diff56ann)),r2(AMeasure(d$diff56enu,d$diff56ann)),r2(AMeasure(d$diff56com,d$diff56enu)))



# RQ3: Preference

pref<-d[,c(29,30,31)]
pref[,1] <- factor(pref[,1],levels=c("ann","com","enu","none"), ordered = TRUE)
pref[,2] <- factor(pref[,2],levels=c("ann","com","enu","none"), ordered = TRUE)
pref[,3] <- factor(pref[,3],levels=c("ann","com","enu","none"), ordered = TRUE)
levels(pref[,1]) <- list("Enumerative"="enu", "Compositional"="com", "Annotative"="ann", "None"="none")
levels(pref[,2]) <- list("Enumerative"="enu", "Compositional"="com", "Annotative"="ann", "None"="none")
levels(pref[,3]) <- list("Enumerative"="enu", "Compositional"="com", "Annotative"="ann", "None"="none")
freq=table(col(pref), as.matrix(pref)) 
freq=(freq*100)/nrow(d)



